@@ -1287,9 +1287,9 @@ and not with the non-debug version.
     if isMacOS() and shallCreateAppBundle() and not options.macos_icon_path:
         Tracing.options_logger.warning(
             """\
-For application bundles, you ought to specify an icon with '--macos-app-icon'.", \
-otherwise a dock icon may not be present. Specify 'none' value to disable \
-this warning."""
+For application bundles, you ought to specify an icon with '--macos-app-icon=...' \
+otherwise a dock icon may not be present. Specify the value as 'none' value \
+to disable this warning."""
         )
 
     if (
@@ -2238,6 +2238,9 @@ def _checkIconPaths(icon_paths):
 
 def getWindowsIconPaths():
     """*list of str*, values of ``--windows-icon-from-ico``"""
+    if not isWin32Windows():
+        return ()
+
     return _checkIconPaths(options.windows_icon_path)
 
 
@@ -2271,6 +2274,9 @@ def getMacOSIconPaths():
 
 def getWindowsIconExecutablePath():
     """*str* or *None* if not given, value of ``--windows-icon-from-exe``"""
+    if not isWin32Windows():
+        return None
+
     return options.icon_exe_path
 
 
